﻿namespace U2UConsult.Silverlight.ThemeBuilder.Client.ViewModels
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Windows;
    using System.Windows.Controls.Theming;
    using System.Windows.Input;
    using U2UConsult.Silverlight.Framework.Helpers;

    /// <summary>
    /// Main View VM.
    /// </summary>
    public class MainViewModel : INotifyPropertyChanged
    {
        /// <summary>
        /// Theme changed command.
        /// </summary>
        private RelayCommand themeChangedCommand;

        /// <summary>
        /// Current theme name.
        /// </summary>
        private string themeName = "Default";

        /// <summary>
        /// Initializes a new instance of the <see cref="MainViewModel"/> class.
        /// </summary>
        public MainViewModel()
        {
            this.themeChangedCommand = new RelayCommand(this.ThemeChanged_Execute);
        }

        /// <summary>
        /// Occurs when a property value changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Gets the test data.
        /// </summary>
        public List<Models.Beer> TestData
        {
            get
            {
                return new List<Models.Beer>() 
                { 
                    new Models.Beer() { Name = "Chimay Bleue", Taste = "Spicy", Alcohol = 9, Color = "Dark" },
                    new Models.Beer() { Name = "Hopus", Taste = "Bitter", Alcohol = 8, Color = "Light" },
                    new Models.Beer() { Name = "Kriek Xtreme", Taste = "Fruity", Alcohol = 4, Color = "Red" }
                };
            }
        }

        /// <summary>
        /// Gets the theme changed command.
        /// </summary>
        public ICommand ThemeChangedCommand
        {
            get
            {
                return this.themeChangedCommand;
            }
        }

        /// <summary>
        /// Gets the name of the theme.
        /// </summary>
        /// <value>
        /// The name of the theme.
        /// </value>
        public string ThemeName
        {
            get
            {
                return this.themeName;
            }

            private set
            {
                this.themeName = value;
                this.PropertyChanged.Raise(this, o => o.ThemeName);
            }
        }

        /// <summary>
        /// Theme changed command action.
        /// </summary>
        /// <param name="parameter">The parameter.</param>
        public void ThemeChanged_Execute(object parameter)
        {
            Theme themedRegion = (Theme)((FrameworkElement)Application.Current.RootVisual).FindName("ThemedRegion");
            this.ThemeName = parameter as string;

            if (this.themeName == null)
            {
                themedRegion.ThemeUri = null;
            }
            else
            {
                themedRegion.ThemeUri = new Uri("/System.Windows.Controls.Theming." + this.themeName + ";component/Theme.xaml", UriKind.RelativeOrAbsolute);
            }
        }
    }
}
